# DF for AutoSklearn

Extension of AutoSklearnClassifier with DF21 - [CascadeForestClassifier](https://deep-forest.readthedocs.io/en/latest/index.html) - a Deep Forest implementantion.

## Requirements

* numpy version <= 1.19
* installation of CascadeForestClassifier
* input variables have to be converted to numeric without missing values 
* output variables also should be converted to numeric values (you can use sklearn LabelEncoder)

